@@ -111,3 +111,10 @@
 #define HAVE_IMAGE_MAGICK 1
 
 #define LIBEXEC_INSTALL_DIR "/usr/local/libexec"
+
+#define CMAKE_VERSION_STRING        "4.2.3"
+#define CMAKE_CXX_COMPILER_ID       "Clang"
+#define CMAKE_CXX_COMPILER_VERSION  "19.1.7"
+#define CMAKE_HOST_PRETTY_NAME      ""
+#define CMAKE_SYSTEM_PROCESSOR      "amd64"
+#define CMAKE_HOST_SYSTEM_PROCESSOR "amd64"
