@@ -7,7 +7,7 @@
  * Description : a wrapper class for an ICC color profile
  *
  * SPDX-FileCopyrightText: 2005-2006 by F.J. Cruz <fj dot cruz at supercable dot es>
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -187,6 +187,12 @@ public:
      */
     LcmsLock();
     ~LcmsLock();
+
+private:
+
+    // Disable
+    LcmsLock(const LcmsLock&)            = delete;
+    LcmsLock& operator=(const LcmsLock&) = delete;
 };
 
 } // namespace Digikam
